@@ -20,7 +20,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.30';
+$VERSION = '1.32';
 
 # older Casio maker notes (ref 1)
 %Image::ExifTool::Casio::Main = (
@@ -485,6 +485,7 @@ $VERSION = '1.30';
             '2 0 0' => 'Mist Removal',
             '3 0 0' => 'Vivid Landscape',
             # have also seen '1 1 1', '2 2 4', '4 3 3', '4 4 4'
+            # '0 0 14' and '0 0 42' - premium auto night shot (EX-Z2300)
         },
     },
     0x3000 => {
@@ -537,6 +538,7 @@ $VERSION = '1.30';
            3 => 'Single-Area Auto Focus',
            5 => 'Infinity', #PH
            6 => 'Multi-Area Auto Focus',
+           8 => 'Super Macro', #PH (EX-Z2300)
         },
     },
     0x3006 => {
@@ -632,6 +634,12 @@ $VERSION = '1.30';
         PrintConv => {
             0 => 'Normal',
             8 => 'Silent Movie',
+            39 => 'HDR', # (EX-ZR10)
+            45 => 'Premium Auto', # (EX-2300)
+            47 => 'Painting', # (EX-2300)
+            49 => 'Crayon Drawing', # (EX-2300)
+            51 => 'Panorama', # (EX-ZR10)
+            52 => 'Art HDR', # (EX-ZR10)
         },
     },
     0x301c => { #3
@@ -693,6 +701,7 @@ $VERSION = '1.30';
             1 => 'Makeup',
             2 => 'Mist Removal',
             3 => 'Vivid Landscape',
+            16 => 'Art Shot', # (EX-Z2300)
         },
     },
     0x3103 => { #5
@@ -736,13 +745,14 @@ $VERSION = '1.30';
         ValueConvInv => '$val <= 60 ? $val * 1000 : int($val) . " 0"',
     },
     # 0x4002 - AVI videos, related to video quality or size - PH
-    0x4003 => { #PH (AVI videos)
+    0x4003 => { #PH (AVI and MOV videos)
         Name => 'VideoQuality',
         Writable => 'int16u',
         PrintConv => {
             1 => 'Standard',
             # 2 - could this be LP?
-            3 => 'HD',
+            3 => 'HD (720p)',
+            4 => 'Full HD (1080p)', # (EX-ZR10, 30fps 1920x1080)
             5 => 'Low', # used in High Speed modes
         },
     },
@@ -824,7 +834,7 @@ Casio maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2011, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
