@@ -5,6 +5,7 @@
 #
 # Revisions:    2009/08/28 - P. Harvey created
 #               2010/01/20 - P. Harvey complete re-write
+#               2010/07/16 - P. Harvey added UTF-16 support
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Charset;
@@ -13,7 +14,7 @@ use strict;
 use vars qw($VERSION %csType);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.02';
+$VERSION = '1.06';
 
 my %charsetTable;   # character set tables we've loaded
 
@@ -68,11 +69,12 @@ my %unicode2byte = (
     Turkish      => 0x101,
     Vietnam      => 0x101,
     MacArabic    => 0x103, # (directional characters not supported)
+    PDFDoc       => 0x181,
     Unicode      => 0x200, # (UCS2)
     UCS2         => 0x200,
+    UTF16        => 0x200,
     Symbol       => 0x201,
     JIS          => 0x201,
-    ShiftJIS     => 0x281,
     UCS4         => 0x400,
     MacChineseCN => 0x803,
     MacChineseTW => 0x803,
@@ -81,8 +83,28 @@ my %unicode2byte = (
     MacRSymbol   => 0x803,
     MacThai      => 0x803,
     MacJapanese  => 0x883,
+    ShiftJIS     => 0x883,
 );
 
+#------------------------------------------------------------------------------
+# Load character set module
+# Inputs: 0) Module name
+# Returns: Reference to lookup hash, or undef on error
+sub LoadCharset($)
+{
+    my $charset = shift;
+    my $conv = $charsetTable{$charset};
+    unless ($conv) {
+        # load translation module
+        my $module = "Image::ExifTool::Charset::$charset";
+        no strict 'refs';
+        if (%$module or eval "require $module") {
+            $conv = $charsetTable{$charset} = \%$module;
+        }
+    }
+    return $conv;
+}
+
 #------------------------------------------------------------------------------
 # Decompose string with specified encoding into an array of integer code points
 # Inputs: 0) ExifTool object ref (or undef), 1) string, 2) character set name,
@@ -100,17 +122,11 @@ sub Decompose($$$;$)
     my (@uni, $conv);
 
     if ($type & 0x001) {
-        $conv = $charsetTable{$charset};
+        $conv = LoadCharset($charset);
         unless ($conv) {
-            # load translation module
-            my $module = "Image::ExifTool::Charset::$charset";
-            no strict 'refs';
-            unless (%$module or eval "require $module") {
-                # (shouldn't happen)
-                $exifTool->Warn("Invalid character set $charset") if $exifTool;
-                return \@uni;   # error!
-            }
-            $conv = $charsetTable{$charset} = \%$module;
+            # (shouldn't happen)
+            $exifTool->Warn("Invalid character set $charset") if $exifTool;
+            return \@uni;   # error!
         }
     } elsif ($type == 0x100) {
         # convert ASCII and UTF8 (treat ASCII as UTF8)
@@ -139,9 +155,11 @@ sub Decompose($$$;$)
     } elsif ($type & 0x600) {   # 2-byte or 4-byte fixed-width characters
         my $unknown;
         my $byteOrder = $_[3];
-        if (not $byteOrder or $byteOrder eq 'Unknown') {
-            $unknown = 1 if $byteOrder;
+        if (not $byteOrder) {
             $byteOrder = GetByteOrder();
+        } elsif ($byteOrder eq 'Unknown') {
+            $byteOrder = GetByteOrder();
+            $unknown = 1;
         }
         my $fmt = $byteOrder eq 'MM' ? 'n*' : 'v*';
         if ($type & 0x400) {    # 4-byte
@@ -179,6 +197,16 @@ sub Decompose($$$;$)
                     @uni = unpack($fmt, $val);
                 }
             }
+            # handle surrogate pairs of UTF-16
+            if ($charset eq 'UTF16') {
+                my $i;
+                for ($i=0; $i<$#uni; ++$i) {
+                    next unless ($uni[$i]   & 0xfc00) == 0xd800 and
+                                ($uni[$i+1] & 0xfc00) == 0xdc00;
+                    my $cp = 0x10000 + (($uni[$i] & 0x3ff) << 10) + ($uni[$i+1] & 0x3ff);
+                    splice(@uni, $i, 2, $cp);
+                }
+            }
         } elsif ($unknown) {
             # count encoding errors as we do the translation
             my $e1 = 0;
@@ -237,16 +265,17 @@ sub Decompose($$$;$)
 
 #------------------------------------------------------------------------------
 # Convert array of code point integers into a string with specified encoding
-# Inputs: 0) ExifTool ref, 1) unicode character array ref,
+# Inputs: 0) ExifTool ref (or undef), 1) unicode character array ref,
 #         2) character set (note: not all types are supported)
 #         3) byte order ('MM' or 'II', multi-byte sets only, defaults to current byte order)
-# Returns: converted string (truncated at null character if it exists)
+# Returns: converted string (truncated at null character if it exists), empty on error
 # Notes: converts elements of input character array to new code points
 # - ExifTool ref may be undef provided $charset is defined
 sub Recompose($$;$$)
 {
+    local $_;
     my ($exifTool, $uni, $charset) = @_; # ($byteOrder assigned later if required)
-    my $outVal;
+    my ($outVal, $conv, $inv);
     $charset or $charset = $$exifTool{OPTIONS}{Charset};
     my $csType = $csType{$charset};
     if ($csType == 0x100) {     # UTF8 (also treat ASCII as UTF8)
@@ -260,30 +289,38 @@ sub Recompose($$;$$)
         $outVal =~ s/\0.*//s;   # truncate at null terminator
         return $outVal;
     }
-    # get reference to inverse lookup table
-    my $inv = $unicode2byte{$charset};
-    if (not $inv and $csType & 0x801) {
-        # generate inverse lookup
-        my $conv = "Image::ExifTool::Charset::$charset";
-        if (not $csType or $csType & 0x802 or not eval "require $conv") {
-            $exifTool->Warn("Invalid destination charset $charset") if $exifTool;
+    # get references to forward and inverse lookup tables
+    if ($csType & 0x801) {
+        $conv = LoadCharset($charset);
+        unless ($conv) {
+            $exifTool->Warn("Missing charset $charset");
             return '';
         }
-        # prepare table to convert from Unicode to 1-byte characters
-        my ($char, %inv);
-        no strict 'refs';
-        foreach $char (keys %$conv) {
-            $inv{$$conv{$char}} = $char;
+        $inv = $unicode2byte{$charset};
+        # generate inverse lookup if necessary
+        unless ($inv) {
+            if (not $csType or $csType & 0x802) {
+                $exifTool->Warn("Invalid destination charset $charset") if $exifTool;
+                return '';
+            }
+            # prepare table to convert from Unicode to 1-byte characters
+            my ($char, %inv);
+            foreach $char (keys %$conv) {
+                $inv{$$conv{$char}} = $char;
+            }
+            $inv = $unicode2byte{$charset} = \%inv;
         }
-        $inv = $unicode2byte{$charset} = \%inv;
     }
     if ($csType & 0x100) {      # 1-byte fixed-width
         # convert to specified character set
         foreach (@$uni) {
             next if $_ < 0x80;
             $$inv{$_} and $_ = $$inv{$_}, next;
-            next if $_ < 0x100;
-            $_ = ord('?');  # set to '?'
+            # our tables omit 1-byte characters with the same values as Unicode,
+            # so pass them straight through after making sure there isn't a
+            # different character with this byte value
+            next if $_ < 0x100 and not $$conv{$_};
+            $_ = ord('?');  # set invalid characters to '?'
             if ($exifTool and not $$exifTool{EncodingError}) {
                 $exifTool->Warn("Some character(s) could not be encoded in $charset");
                 $$exifTool{EncodingError} = 1;
@@ -297,6 +334,18 @@ sub Recompose($$;$$)
         if ($inv) {
             $$inv{$_} and $_ = $$inv{$_} foreach @$uni;
         }
+        # generate surrogate pairs of UTF-16
+        if ($charset eq 'UTF16') {
+            my $i;
+            for ($i=0; $i<@$uni; ++$i) {
+                next unless $$uni[$i] >= 0x10000 and $$uni[$i] < 0x10ffff;
+                my $t = $$uni[$i] - 0x10000;
+                my $w1 = 0xd800 + (($t >> 10) & 0x3ff);
+                my $w2 = 0xdc00 + ($t & 0x3ff);
+                splice(@$uni, $i, 1, $w1, $w2);
+                ++$i;   # skip surrogate pair
+            }
+        }
         # pack as 2- or 4-byte integer in specified byte order
         my $byteOrder = $_[3] || GetByteOrder();
         my $fmt = $byteOrder eq 'MM' ? 'n*' : 'v*';
@@ -323,11 +372,11 @@ This module is required by Image::ExifTool.
 This module contains routines used by ExifTool to translate special
 character sets.  Currently, the following character sets are supported:
 
-  UTF8, UCS2, UCS4, Arabic, Baltic, Cyrillic, Greek, Hebrew, JIS, Latin,
-  Latin2, MacArabic, MacChineseCN, MacChineseTW, MacCroatian, MacCyrillic,
-  MacGreek, MacHebrew, MacIceland, MacJapanese, MacKorean, MacLatin2,
-  MacRSymbol, MacRoman, MacRomanian, MacThai, MacTurkish, RSymbol,
-  ShiftJIS, Symbol, Thai, Turkish, Vietnam
+  UTF8, UTF16, UCS2, UCS4, Arabic, Baltic, Cyrillic, Greek, Hebrew, JIS,
+  Latin, Latin2, MacArabic, MacChineseCN, MacChineseTW, MacCroatian,
+  MacCyrillic, MacGreek, MacHebrew, MacIceland, MacJapanese, MacKorean,
+  MacLatin2, MacRSymbol, MacRoman, MacRomanian, MacThai, MacTurkish,
+  PDFDoc, RSymbol, ShiftJIS, Symbol, Thai, Turkish, Vietnam
 
 However, only some of these character sets are available to the user via
 ExifTool options; the multi-byte character sets are used only internally
@@ -335,7 +384,7 @@ when decoding certain types of information.
 
 =head1 AUTHOR
 
-Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2011, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
