@@ -31,7 +31,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.04';
+$VERSION = '1.06';
 
 # program map table "stream_type" lookup (ref 6/1)
 my %streamType = (
@@ -117,8 +117,8 @@ my %noSyntax = (
     VARS => { NO_ID => 1 },
     NOTES => q{
         The MPEG-2 transport stream is used as a container for many different
-        audio/video formats (including AVCHD).  This table represents information
-        extracted from the MPEG-2 transport headers.
+        audio/video formats (including AVCHD).  This table lists information
+        extracted from M2TS files.
     },
     VideoStreamType => {
         PrintHex => 1,
@@ -149,7 +149,7 @@ my %noSyntax = (
     },
     AudioBitrate => {
         PrintConvColumns => 2,
-        PrintConv => {
+        ValueConv => {
             0 => 32000,
             1 => 40000,
             2 => 48000,
@@ -189,6 +189,7 @@ my %noSyntax = (
             49 => '576000 max',
             50 => '640000 max',
         },
+        PrintConv => 'ConvertBitrate($val)',
     },
     SurroundMode => {
         PrintConv => {
@@ -282,8 +283,8 @@ sub ParsePID($$$$$)
     } elsif ($type == 0x1b) {
         # H.264 Video
         require Image::ExifTool::H264;
-        Image::ExifTool::H264::ParseH264Video($exifTool, $dataPt);
-        # process additional H264 frames with ExtractEmbedded option
+        $more = Image::ExifTool::H264::ParseH264Video($exifTool, $dataPt);
+        # force parsing additional H264 frames with ExtractEmbedded option
         $more = 1 if $exifTool->Options('ExtractEmbedded');
     } elsif ($type == 0x81 or $type == 0x87 or $type == 0x91) {
         # AC-3 audio
@@ -622,7 +623,7 @@ video.
 
 =head1 AUTHOR
 
-Copyright 2003-2010, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2011, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
